Home — StarCluster v0.92.1 documentation

### Navigation

- index
- Home |
- Install |
- Quick-Start |
- Config |
- Manual |
- Contribute |
- Support

# StarCluster documentation (v. 0.92.1)

StarCluster is a utility for creating and managing distributed computing clusters hosted on Amazon's Elastic Compute Cloud (EC2). StarCluster utilizes Amazon's EC2 web service to create and destroy clusters of Linux virtual machines on demand.

StarCluster aims to be an easy-to-use and extensible cluster computing toolkit for the cloud. The sections below are divided into user and developer documentation.

## User Documentation

Overview Introduction to StarCluster. Install instructions How to install StarCluster. Quick-Start Tutorial A Quick-Start tutorial for StarCluster newcomers. Support Reporting bugs, issues, questions, feature requests, etc. | User Manual Complete user manual for StarCluster Guides Task-oriented guides Plugins Plugin-specific documentation FAQ Frequently Asked Questions

## StarCluster Development

Contribute Taking part in StarCluster's development. Hacking Design rationales, source organization. | Features Current and planned features. TODO Remaining development tasks.

## Indices and Tables

Table of Contents Lists all sections and subsections. Search Page Search this documentation. | Index All functions, classes, terms.

### Navigation

- index
- Home |
- Install |
- Quick-Start |
- Config |
- Manual |
- Contribute |
- Support